package	jp.co.sds_corp.ratemixer.fx.layout;

import java.math.BigDecimal;
import java.text.DecimalFormat;

import jp.co.sds_corp.ratemixer.fx.FxRate;
import jp.co.sds_corp.transfer.IData;
import jp.co.sds_corp.transfer.layout.IConverter;
import jp.co.sds_corp.util.common.CmnDate;

/**
* レートを編集して出力します。
*/
public class RateConverter implements IConverter
{
	/** タイプ：通貨1 */
	public static final int TYPE_CCY1 = 1;
	/** タイプ：通貨2 */
	public static final int TYPE_CCY2 = 2;
	/** タイプ：期間 */
	public static final int TYPE_TERM = 3;
	/** タイプ：bid rate */
	public static final int TYPE_BID = 4;
	/** タイプ：ask rate */
	public static final int TYPE_ASK = 5;
	/** タイプ：mid rate */
	public static final int TYPE_MID = 6;
	/** タイプ：受信日時 */
	public static final int TYPE_RECV = 7;

	int type = 0;
	String pattern;

	/**
	* 指定されたタイプとフォーマット文字列でRateConverterを作成します。
	* @param	type	編集タイプ
	* @param	pattern	フォーマット文字列
	*/
	public RateConverter( int type, String pattern ) {
		this.type = type;
		this.pattern = pattern;
	}

	/**
	* 文字列を編集して出力します。
	* @param	rate	編集元のレート
	* @return	編集結果の文字列
	*/
	public String convert( IData rate ) {
		String ret = null;
		FxRate fx = (FxRate )rate;
		switch ( type ) {
		case TYPE_CCY1:
			ret = fx.getCcyPair().getCcy1().getCode();
			break;
		case TYPE_CCY2:
			ret = fx.getCcyPair().getCcy2().getCode();
			break;
		case TYPE_TERM:
			ret = fx.getTerm();
			break;
		case TYPE_BID:
			ret = convertDecimal( fx.getBid() );
			break;
		case TYPE_ASK:
			ret = convertDecimal( fx.getAsk() );
			break;
		case TYPE_MID:
			ret = convertDecimal( fx.getBid() );
			break;
		case TYPE_RECV:
			ret = convertDate( fx.getRecvTime() );
			break;
		}
		return ret;
	}

	/**
	* BigDecimalの項目を編集して文字列として出力します。
	*/
	protected String convertDecimal( BigDecimal dec ) {
		String ret = null;
		if ( pattern == null ) {
			ret = dec.toString();
		} else {
			DecimalFormat df = new DecimalFormat( pattern );
			ret = df.format( dec );
		}
		return ret;
	}

	/**
	* 日付項目を編集して文字列として出力します。
	*/
	protected String convertDate( CmnDate date ) {
		String ret = null;
		if ( pattern == null ) {
			pattern = "yyyy-MM-dd HH:mm:ss";
		}
		ret = date.format( pattern );
		return ret;
	}

	/**
	* 編集タイプ(type)を設定します。
	* @param	var		設定するデータ
	*/
	public void setType( int var ) {
		this.type = var ;
	}
	/**
	* 編集タイプ(type)を取得します。
	* @return	typeの内容
	*/
	public int getType() {
		return type;
	}

	/**
	* フォーマット文字列(pattern)を設定します。
	* @param	var		設定するデータ
	*/
	public void setPattern( String var ) {
		this.pattern = var ;
	}
	/**
	* フォーマット文字列(pattern)を取得します。
	* @return	patternの内容
	*/
	public String getPattern() {
		return pattern;
	}

}
